import QtQuick 2.4

FocusScope {
    id: root
    objectName: "alertView"

    property var model: _testModel;
    property bool isOpen: state == "open"

    function openView() {
        if (root.state != "open") {
            root.state = "open";
        }
    }

    function closeView() {
        if (root.state != "closed") {
            root.state = "closed";
        }
    }

    function close() {
        root.model.clear();
    }

    state: "closed"

    states: [
        State {
            name: "open"
        },
        State {
            name: "closed"
        }
    ]

    transitions: [
        Transition {
            id: openTransition
            to: "open"
            onRunningChanged: {
                if (running) {
                    root.visible = true;
                }
            }
        },
        Transition {
            id: closeTransition
            to: "closed"
            onRunningChanged: {
                if (!running) {
                    root.visible = false;
                }
            }
        }
    ]

    ListModel{
        id: _testModel
    }
    Timer{
        property int count: 0
        running: true
        interval: 1000
        repeat: true
        onTriggered: {
            count++
            console.warn("append data")
            _testModel.append({"alertInfo":
                                  {
                                      "message":"This is the alert " + count,
                                      "title":"Alert Title " + count
                                  },
                                  "alertAction":"open"
                              })
        }
    }

    Connections {
        target: alertStack
        onStateChanged: {
            switch (alertStack.state) {
            case "open":
                root.openView();
                break;
            case "closed":
                root.closeView();
                break;
            }
        }
    }

    NotificationStack {
        id: alertStack
        rootObjectName: root.objectName
        width: root.width
        height: 150
        model: root.model
        delegate: Component {
            Rectangle{
                width: parent.width
                height: 200
                color: "green"
                Text {
                    anchors.centerIn: parent
                    text: model.alertInfo.message
                }
            }
        }
    }
}
